import sys

from gpaw import Calculator
from ase import Atoms, QuasiNewton, FixAtoms

if len(sys.argv) != 2:
    print 'Please write exactly one argument'

name = sys.argv[-1]
if name == 'grid':
    basis = {}
    eigensolver = 'rmm-diis'
else:
    basis = name
    eigensolver = 'lcao'

a = 10.
d = 1.

system = Atoms('H2O',
               positions=[[0., 0., -d],
                          [0., 0., +d],
                          [0., 0., 0.]],
               cell=(a, a, a))

system.center()

# break symmetry slightly
system.positions[0,1] += 1e-2
system.positions[1,0] += 1e-2

constraint = FixAtoms(mask=[0, 0, 1])
system.set_constraint(constraint)

calc = Calculator(eigensolver=eigensolver,
                  basis=basis,
                  txt='h2o.%s.txt' % name)
system.set_calculator(calc)
system.get_potential_energy()

qn = QuasiNewton(system, trajectory='h2o.%s.traj' % name)
qn.run(fmax=.003)

calc.write('h2o.%s.gpw' % name)
